@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import sys
+import gffutils
 import pandas as pd 
 from Bio.Seq import Seq
 from collections import defaultdict
@@ -7,6 +8,8 @@ from collections import defaultdict
 # table header 
 ['TranscriptID','Chrom', 'Strand','CDS Interval','uORF Start','uORF End','uORF Type','uORF Length','uORF']
 
+
+
 def uorf(transcript_id, chrom, strand, matural_transcript, coding_sequence):
     '''
     parameters:
@@ -65,27 +68,28 @@ def uorf(transcript_id, chrom, strand, matural_transcript, coding_sequence):
 
 
 
-def get_uorf(db, genome, transcript_id, output):
+def get_uorf(args):
     '''
     parameters:
-     db: database generated by gffutils 
-     genome: genome fasta 
-     transcript_id: transcript id 
-     output: output file
+        args: parse from argparse
+    return:
+        elements write to a file or stdout
     '''
+    db = gffutils.FeatureDB(args.database, keep_order=True)
+    
     uORF_seq = pd.DataFrame(columns=['TranscriptID','Chrom','Strand','CDS Interval','uORF Start','uORF End','uORF Type','uORF Length','uORF'])
     index = 0
-    if not transcript_id:
+    if not args.transcript:
         for t in db.features_of_type('mRNA', order_by='start'):
             # primary transcript (pt) 是基因组上的转录本的序列，
             # 有的会包括intron，所以提取的序列和matural transcript 不一致
             # print(t)
-            pt = t.sequence(genome, use_strand=True)
+            pt = t.sequence(args.genome, use_strand=True)
             # matural transcript (mt)
             # exon 提取的是转录本内成熟的MRNA的序列,即外显子收尾相连的matural transcript
             mt = ''
             for e in db.children(t, featuretype='exon', order_by='start'):
-                s = e.sequence(genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
+                s = e.sequence(args.genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
                 mt += s
             mt = Seq(mt)
             if t.strand == '-':
@@ -94,7 +98,7 @@ def get_uorf(db, genome, transcript_id, output):
             cds = ''
             for c in db.children(t, featuretype='CDS', order_by='start'):
                 #print(c)
-                s = c.sequence(genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
+                s = c.sequence(args.genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
                 cds += s
             cds = Seq(cds)
             if t.strand == '-':
@@ -108,19 +112,19 @@ def get_uorf(db, genome, transcript_id, output):
                     index += 1
             #if index > 100:
             #    break
-        uORF_seq.to_csv(output, sep=',', index=False)
+        uORF_seq.to_csv(args.output, sep=',', index=False)
     else:
         for t in db.features_of_type('mRNA', order_by='start'):
             # primary transcript (pt) 是基因组上的转录本的序列，
             # 有的会包括intron，所以提取的序列和matural transcript 不一致
             # print(t)
-            if transcript_id in t.id:
-                pt = t.sequence(genome, use_strand=True)
+            if args.transcript in t.id:
+                pt = t.sequence(args.genome, use_strand=True)
                 # matural transcript (mt)
                 # exon 提取的是转录本内成熟的MRNA的序列,即外显子收尾相连的matural transcript
                 mt = ''
                 for e in db.children(t, featuretype='exon', order_by='start'):
-                    s = e.sequence(genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
+                    s = e.sequence(args.genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
                     mt += s
                 mt = Seq(mt)
                 if t.strand == '-':
@@ -129,7 +133,7 @@ def get_uorf(db, genome, transcript_id, output):
                 cds = ''
                 for c in db.children(t, featuretype='CDS', order_by='start'):
                     #print(c)
-                    s = c.sequence(genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
+                    s = c.sequence(args.genome, use_strand=False) # 不反向互补，对于负链要得到全部的cds后再一次性反向互补
                     cds += s
                 cds = Seq(cds)
                 if t.strand == '-':
@@ -141,5 +145,5 @@ def get_uorf(db, genome, transcript_id, output):
                         #print(it)
                         uORF_seq.loc[index] = it
                         index += 1
-                uORF_seq.to_csv(output, sep=',', index=False)
+                uORF_seq.to_csv(args.output, sep=',', index=False)
                 break 
